@@ -63,7 +63,7 @@ fn main() -> Result<()> {
 
     // TODO: Maybe attach these strings to the ModuleType enum somehow
     // For each module type, see if it occurs on the command line and process it
-    for module_type_str in &["assembly", "concept", "procedure", "reference"] {
+    for module_type_str in ["assembly", "concept", "procedure", "reference", "snippet"] {
         // Check if the given module type occurs on the command line
         if let Some(titles_iterator) = cmdline_args.values_of(module_type_str) {
             let mut modules = process_module_type(titles_iterator, module_type_str, &options);
@@ -83,10 +83,9 @@ fn main() -> Result<()> {
     // * It must be generated after the other modules so that it can use their include statements
     if let Some(title) = cmdline_args.value_of("include-in") {
         // Gather all include statements for the other modules
-        // TODO: Figure out if this can be done without calling .to_owned on all the Strings
         let include_statements: Vec<String> = non_populated
-            .iter()
-            .map(|module| module.include_statement.clone())
+            .into_iter()
+            .map(|module| module.include_statement)
             .collect();
 
         // The include_statements should never be empty thanks to the required group in clap
@@ -122,6 +121,7 @@ fn process_module_type(
         "concept" => ModuleType::Concept,
         "procedure" => ModuleType::Procedure,
         "reference" => ModuleType::Reference,
+        "snippet" => ModuleType::Snippet,
         _ => unimplemented!(),
     };
 
@@ -204,6 +204,20 @@ mod tests {
         assert_eq!(reference.text, pre_generated);
     }
 
+    /// Test that we generate the snippet file that we expect.
+    #[test]
+    fn test_snippet_file() {
+        let mod_type = ModuleType::Snippet;
+        let mod_title = "Some notes in a snippet file";
+        let options = basic_options();
+        let snippet = Module::new(mod_type, mod_title, &options);
+
+        let pre_generated =
+            include_str!("../data/generated/snip_some-notes-in-a-snippet-file.adoc");
+
+        assert_eq!(snippet.text, pre_generated);
+    }
+
     // These values strip down the modules to the bare minimum.
     fn minimal_options() -> Options {
         Options {
@@ -266,4 +280,17 @@ mod tests {
 
         assert_eq!(reference.text, pre_generated);
     }
+
+    /// Test that we generate the snippet file that we expect.
+    #[test]
+    fn test_minimal_snippet() {
+        let mod_type = ModuleType::Snippet;
+        let mod_title = "Minimal snippet";
+        let options = minimal_options();
+        let snippet = Module::new(mod_type, mod_title, &options);
+
+        let pre_generated = include_str!("../data/generated/minimal-snippet.adoc");
+
+        assert_eq!(snippet.text, pre_generated);
+    }
 }
