@@ -1,11 +1,13 @@
-use log::{debug, error};
-use regex::{Regex, RegexBuilder};
 /// This module provides functionality to validate (lint) existing module and assembly files,
 /// to check if the files meet the template structure and other requirements.
 use std::fmt;
 use std::fs;
 use std::path::Path;
 
+use color_eyre::eyre::{Context, Result};
+use log::debug;
+use regex::{Regex, RegexBuilder};
+
 use crate::module::ModuleType;
 
 #[derive(Clone, Copy, Debug)]
@@ -96,20 +98,14 @@ impl fmt::Display for IssueReport {
 
 /// The main validation function. Checks all possible issues in a single file, loaded from a file name.
 /// Prints the issues to the standard output.
-pub fn validate(file_name: &str) {
+pub fn validate(file_name: &str) -> Result<()> {
     debug!("Validating file `{}`", file_name);
 
     let path = Path::new(file_name);
     let base_name = path.file_name().unwrap().to_str().unwrap();
 
-    let read_result = fs::read_to_string(path);
-    let content = match read_result {
-        Ok(content) => content,
-        Err(err) => {
-            error!("Error reading file `{}`: {}", file_name, err);
-            return;
-        }
-    };
+    let content =
+        fs::read_to_string(path).context(format!("Error reading file `{}`.", file_name))?;
 
     let mod_type = determine_mod_type(base_name, &content);
 
@@ -127,6 +123,8 @@ pub fn validate(file_name: &str) {
     };
 
     report_issues(reports, file_name);
+
+    Ok(())
 }
 
 /// Print a sorted, human-readable report about the issues found in the file
@@ -344,7 +342,6 @@ mod content {
             reports.push(experimental_issue);
         }
 
-        reports.append(check_path_xrefs(content).as_mut());
         reports.append(check_metadata_variable(content).as_mut());
 
         reports
@@ -389,7 +386,8 @@ mod content {
         results
     }
 
-    /// Check that the abstract flag exists in the file and that it's followed by a paragraph.
+    /// Check that the abstract flag is followed by a paragraph,
+    /// if it exists at all. The abstract flag is not required.
     fn check_abstract_flag(content: &str) -> Option<IssueReport> {
         let abstract_regex = Regex::new(r#"^\[role="_abstract"\]"#).unwrap();
         let abstract_flag = find_first_occurrence(content, abstract_regex);
@@ -424,12 +422,9 @@ mod content {
                 debug!("No lines after the abstract.");
                 Some(no_paragraph_report)
             }
+        // If the file contains no abstract tag, report no error. This is supported format.
         } else {
-            Some(IssueReport {
-                line_number: None,
-                description: "The file is missing the _abstract flag. The flag is recommended but not required.",
-                severity: IssueSeverity::Warning,
-            })
+            None
         }
     }
 
@@ -458,38 +453,6 @@ mod content {
             None
         }
     }
-
-    /// Check that supported xrefs are path-based.
-    /// Report issues as warnings because ID-based xrefs might still work in some instances, such as within the file.
-    fn check_path_xrefs(content: &str) -> Vec<IssueReport> {
-        // Check only those xrefs that have labels. Skip unsupported, label-less xrefs, which are reported elsewhere.
-        let xref_regex = Regex::new(r"xref:(\S+)\[\S+.*?\]").unwrap();
-        // This regex checks only the captured content of the xref.
-        let path_based_regex = Regex::new(r"\S+\.(?:adoc|asciidoc)$").unwrap();
-
-        let mut issues = Vec::new();
-
-        for (index, line) in content.lines().enumerate() {
-            if let Some(xref) = xref_regex.captures(line) {
-                if path_based_regex.is_match(
-                    xref.get(1)
-                        .expect("Cannot capture the xref content.")
-                        .as_str(),
-                ) {
-                    // This xref is path-based. This is the correct form. Skip.
-                } else {
-                    // This xref is not path-based. Report.
-                    issues.push(IssueReport {
-                        line_number: Some(index),
-                        description: "This xref does not appear to be path-based. Make sure that it works in your assembly.",
-                        severity: IssueSeverity::Warning,
-                    });
-                }
-            }
-        }
-
-        issues
-    }
 }
 
 // This section groups all module requirements;
